NCAselect.BANOVA<-function(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata,xaxis, yaxis){
NCAselect(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata, xaxis, yaxis,
          Demo=TRUE, BANOVA=TRUE)  ### switch 'Demo=TRUE' for testing
}